@@ -67,7 +67,6 @@ class HN(object):
         while len(soups) < page_limit:
             # get as manu pages as requested
             cur_soup = soups[-1] # get the last seen page's soup
-            time.sleep(INTERVAL_BETWEEN_REQUESTS) # be a good citizen
             next_page = self._get_next_page(cur_soup).lstrip('//')
             next_soup = self._get_soup(next_page) # get the next soup
             if len(next_soup.findChildren('table')) != 0:
@@ -75,7 +74,7 @@ class HN(object):
                 soups.append(next_soup)
             else:
                 break
-            
+            time.sleep(INTERVAL_BETWEEN_REQUESTS) # be a good citizen
         return soups
 
 
@@ -120,7 +119,7 @@ class HN(object):
             info_cells = info.findAll('td') # split in 3 cells
 
             rank = int(info_cells[0].string[:-1])
-            title = info_cells[2].find('a').string.encode('utf-8')
+            title = u'%s' % info_cells[2].find('a').string
             link = info_cells[2].find('a').get('href')
 
             is_self = False # by default all stories are linking posts
@@ -140,7 +139,7 @@ class HN(object):
             if re.match(r'^(\d+)\spoint.*', detail_concern[0].string) is not None:
                 # can be a link or self post
                 points = int(re.match(r'^(\d+)\spoint.*', detail_concern[0].string).groups()[0])
-                submitter = detail_concern[2].string.encode('utf-8')
+                submitter = u'%s' % detail_concern[2].string
                 submitter_profile = '%s/%s' % (BASE_URL, detail_concern[2].get('href'))
                 published_time = ' '.join(detail_concern[3].strip().split()[:3])
                 comment_tag = detail_concern[4]
@@ -157,7 +156,7 @@ class HN(object):
                 points = 0
                 submitter = ''
                 submitter_profile = ''
-                published_time = unicode(detail_concern[0])
+                published_time = u'%s' % detail_concern[0]
                 comment_tag = ''
                 try:
                     story_id = int(re.match(r'.*=(\d+)', link).groups()[0])
